Struct Hunger
pub struct Hunger {
pub food: u32,
pub saturation: f32,
}Fields
food: u32The main hunger bar. This is typically in the range 0..=20.
saturation: f32The amount of saturation the player has.
This isn’t displayed in the vanilla Minecraft GUI, but it’s used
internally by the game. It’s a decrementing counter, and the player’s
Hunger::food only starts decreasing when their saturation reaches 0.
Implementations
impl Hunger
impl Hunger
pub fn is_enough_to_sprint(&self) -> bool
pub fn is_enough_to_sprint(&self) -> bool
Returns true if we have enough food level to sprint.
Note that this doesn’t consider our gamemode or passenger status.