Struct WorldHolder
pub struct WorldHolder {
pub partial: Arc<RwLock<RawRwLock, PartialWorld>>,
pub shared: Arc<RwLock<RawRwLock, World>>,
}Expand description
A component that keeps strong references to our PartialWorld and
World for local players.
This can also act as a convenient way to access the player’s World, since
the alternative is to look up the player’s WorldName in the Worlds
resource.
Fields
partial: Arc<RwLock<RawRwLock, PartialWorld>>The slice of the world that this client actually has loaded, based on its render distance.
The combined PartialWorlds of all clients in the same world.
The distinction between this and partial is mostly only relevant if
you’re using a shared world (i.e. a swarm). If in doubt, prefer to use
the shared world.
Implementations
impl WorldHolder
impl WorldHolder
pub fn new(entity: Entity, shared: Arc<RwLock<RawRwLock, World>>) -> WorldHolder
pub fn new(entity: Entity, shared: Arc<RwLock<RawRwLock, World>>) -> WorldHolder
Create a new WorldHolder for the given entity.
The partial world will be created for you. The render distance will be set to a default value, which you can change by creating a new partial world.